convert_XML: Create BEAST XML file

Description Usage Arguments

View source: R/convert_XML.R

Description

Imports sequences from a file and places them in an XML file generated by BEAUti for use with BEAST.

Usage

1
2
convert_XML(input, datatype, template, file, dates = NULL, location = NULL,
  chainLength = NULL, storeEvery = NULL)

Arguments

input

The name of the input file containing the alignment. Works with .nex, .fasta and .phy files

datatype

The type of data used in the alignment input file. Either 'nucleotide', 'aminoacid', or 'binary'.

template

The name of the BEAST input XML file to be used as a template. This file can be produced by BEAUti

file

The name of the file that the resulting XML file will be written to.

dates

The name of the tab delimited file containing tip date data.

location

The name of the tab delimited file containing location data.

chainLength

An integer determining the length of the MCMC chain. If not stated will stay as the value specified in the original template XML file.

storeEvery

An integer determining how often to store the state. If not stated will stay as the value specified in the original template XML file.


JoelJWilson/BEAUtiXMLconvert documentation built on May 30, 2019, 6:12 a.m.