import_sequences: Import Sequences

Description Usage Arguments Value

View source: R/import_sequences.R

Description

Imports a file containing ID and sequences to a dataframe.

Usage

1

Arguments

file

The name of the input file containing the sequence alignment. Works with .nex, .fasta and .phy files.

Value

A dataframe containing the sequence identifiers as the first column and the sequence data in the second column.


JoelJWilson/BEAUtiXMLconvert documentation built on May 30, 2019, 6:12 a.m.