Imports sequences from a file and places them in an XML file generated by BEAUti for use with BEAST.
1 2 |
input |
The name of the input file containing the alignment. Works with .nex, .fasta and .phy files |
datatype |
The type of data used in the alignment input file. Either 'nucleotide', 'aminoacid', or 'binary'. |
template |
The name of the BEAST input XML file to be used as a template. This file can be produced by BEAUti |
file |
The name of the file that the resulting XML file will be written to. |
dates |
The name of the tab delimited file containing tip date data. |
location |
The name of the tab delimited file containing location data. |
chainLength |
An integer determining the length of the MCMC chain. If not stated will stay as the value specified in the original template XML file. |
storeEvery |
An integer determining how often to store the state. If not stated will stay as the value specified in the original template XML file. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.