Description Usage Arguments Value
View source: R/import_sequences.R
Imports a file containing ID and sequences to a dataframe.
1 |
file |
The name of the input file containing the sequence alignment. Works with .nex, .fasta and .phy files. |
A dataframe containing the sequence identifiers as the first column and the sequence data in the second column.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.